#[repr(i32)]pub enum Result {
Unknown = 0,
Accept = 1,
Abort = 2,
Reject = 3,
RejectFormat = 4,
RejectSender = 5,
}Variants
Unknown = 0
Unknown result, abort all snapshot restoration
Accept = 1
Snapshot accepted, apply chunks
Abort = 2
Abort all snapshot restoration
Reject = 3
Reject this specific snapshot, try others
RejectFormat = 4
Reject all snapshots of this format, try others
RejectSender = 5
Reject all snapshots from the sender(s), try others
Implementations
Sourceimpl Result
impl Result
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.